summaryrefslogtreecommitdiff
path: root/openssl/ssl/dtls1.h
diff options
context:
space:
mode:
Diffstat (limited to 'openssl/ssl/dtls1.h')
-rw-r--r--openssl/ssl/dtls1.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/openssl/ssl/dtls1.h b/openssl/ssl/dtls1.h
index 697ff6e..2900d1d 100644
--- a/openssl/ssl/dtls1.h
+++ b/openssl/ssl/dtls1.h
@@ -108,15 +108,17 @@ extern "C" {
typedef struct dtls1_bitmap_st
{
- PQ_64BIT map;
- unsigned long length; /* sizeof the bitmap in bits */
- PQ_64BIT max_seq_num; /* max record number seen so far */
+ unsigned long map; /* track 32 packets on 32-bit systems
+ and 64 - on 64-bit systems */
+ unsigned char max_seq_num[8]; /* max record number seen so far,
+ 64-bit value in big-endian
+ encoding */
} DTLS1_BITMAP;
struct dtls1_retransmit_state
{
EVP_CIPHER_CTX *enc_write_ctx; /* cryptographic state */
- const EVP_MD *write_hash; /* used for mac generation */
+ EVP_MD_CTX *write_hash; /* used for mac generation */
#ifndef OPENSSL_NO_COMP
COMP_CTX *compress; /* compression */
#else